@@ -446,10 +446,11 @@ class Cognito:
         )
         self._set_tokens(tokens)
 
-    def authenticate(self, password):
+    def authenticate(self, password, client_metadata=None):
         """
         Authenticate the user using the SRP protocol
         :param password: The user's passsword
+        :param client_metadata: Metadata you can provide for custom workflows that RespondToAuthChallenge triggers.
         :return:
         """
         aws = AWSSRP(
@@ -460,7 +461,7 @@ class Cognito:
             client=self.client,
             client_secret=self.client_secret,
         )
-        tokens = aws.authenticate_user()
+        tokens = aws.authenticate_user(client_metadata=client_metadata)
         self._set_tokens(tokens)
 
     def new_password_challenge(self, password, new_password):
@@ -867,3 +868,27 @@ class Cognito:
             ProviderDetails=provider_details,
             **kwargs,
         )
+
+    def describe_user_pool_client(self, pool_id: str, client_id: str):
+        """
+        Returns configuration information of a specified user pool app client
+        :param pool_id: The user pool ID
+        :param client_id: The client ID
+        :return: client json
+        """
+        return self.client.describe_user_pool_client(
+            UserPoolId=pool_id, ClientId=client_id
+        )["UserPoolClient"]
+
+    def admin_update_user_pool_client(self, pool_id: str, client_id: str, **kwargs):
+        """
+        Updates configuration information of a specified user pool app client
+        :param pool_id: The identity pool ID
+        :param client_id: The identity pool name
+        :return:
+        """
+        self.client.update_user_pool_client(
+            UserPoolId=pool_id,
+            ClientId=client_id,
+            **kwargs,
+        )
